[OGDF](../README.md) » Developer's Guide

 * [Build Guide](build.md)
 * [Coding Standards](standards.md)
 * [Compiler Defines](defines.md)
 * [Porting Guide](porting.md)
 * [git, GitHub, and Workflow](workflow.md)

# Developer's Guide

This document aims to answer the most basic questions for developers that are new to the OGDF.
We are using GitHub to coordinate the development, following a simple [workflow](https://guides.github.com/introduction/flow/).

See any of the above topics for detailed information.
